@@ -519,7 +519,7 @@ ensure_all_files (PolkitBackendActionPool *pool)
 
   error = NULL;
   e = g_file_enumerate_children (priv->directory,
-                                 "standard::*",
+                                 "standard::name",
                                  G_FILE_QUERY_INFO_NONE,
                                  NULL,
                                  &error);
@@ -1043,12 +1043,9 @@ process_policy_file (PolkitBackendActionPool *pool,
                      const gchar *xml,
                      GError **error)
 {
-  gboolean ret;
   ParserData pd;
   int xml_res;
 
-  ret = FALSE;
-
   /* clear parser data */
   memset (&pd, 0, sizeof (ParserData));
 
@@ -1111,7 +1108,7 @@ _localize (GHashTable *translations,
            const gchar *lang)
 {
   const gchar *result;
-  gchar lang2[256];
+  gchar **langs;
   guint n;
 
   if (lang == NULL)
@@ -1126,16 +1123,14 @@ _localize (GHashTable *translations,
     goto out;
 
   /* we could have a translation for 'da' but lang=='da_DK'; cut off the last part and try again */
-  strncpy (lang2, lang, sizeof (lang2));
-  for (n = 0; lang2[n] != '\0'; n++)
+  langs = g_get_locale_variants (lang);
+  for (n = 0; langs[n] != NULL; n++)
     {
-      if (lang2[n] == '_')
-        {
-          lang2[n] = '\0';
-          break;
-        }
+      result = (const char *) g_hash_table_lookup (translations, (void *) langs[n]);
+      if (result != NULL)
+        break;
     }
-  result = (const char *) g_hash_table_lookup (translations, (void *) lang2);
+  g_strfreev (langs);
   if (result != NULL)
     goto out;
 
